@@ -256,7 +256,8 @@ class RedisForeignKey(RedisNumber):
     
     def __init__(self, model=None, *args, **kwargs):
         model = check_callable(model)
-        args = map(check_callable, *args)
+        if args:
+            args = list(map(check_callable, *args))
         allowed = True
         if model is None:
             allowed = False
@@ -307,7 +308,8 @@ class RedisManyToMany(RedisList):
     
     def __init__(self, model=None, *args, **kwargs):
         model = check_callable(model)
-        args = map(check_callable, *args)
+        if args:
+            args = list(map(check_callable, *args))
         allowed = True
         if model is None:
             allowed = False
