@@ -36,7 +36,7 @@ class TaskChallenge(RedisModel):
 
 
 class TtlCheckModel(RedisModel):
-    redis_number_with_ttl = RedisNumber(default=0, null=False, ttl=5)
+    redis_number_with_ttl = RedisNumber(default=0, null=False)
 
 
 class MetaTtlCheckModel(RedisModel):
@@ -611,7 +611,7 @@ def run_tests():
         host='localhost',
         port=6379,
         db=0,
-        decode_reponses=True
+        decode_responses=True
     )
     tests = [
         basic_test,
